#!/bin/sh
###################################################################################
# Configuration du pare-feu Netfilter pour une machine linux connecte a Internet #
###################################################################################
# 20041103 - firewall-desktop.sh
# Ce script doit tre excut sous root.
# Il peut tre lanc automatiquement au dmarrage du PC. Pour cela, 
# copiez ce script sous le rpertoire /etc/rc.d et ajoutez  la fin
# du fichier /etc/rc.d/rc.local la ligne suivante :
# sh ./firewall-desktop.sh _interface_
# Si vous modifiez le script, rexcutez-le sous root.
#
# 
# Cette machine peut tre relie au rseau via un modem analogique classique,
# un modem ADSL, une Freebox, ...
# Cette machine ne dispose que d'une connexion rseau dfinie par la variable NETIN.
# Dans le cas de la Freebox relie en Ethernet, l'interface est normalement 'eth0'.
# Pour savoir quelle interface est utilise, faites un "ifconfig" sous root.
# Vous devriez avoir 2 interfaces de listes. 'lo' pour l'interface locale ou 'loopback'
# et celle qui relie votre PC  internet : eth0 ou eth1 ou ppp0 ou ...
#
if [ "$1" == "" ]
then
NETIN=eth0
else
NETIN=$1
fi

#
# La stratgie est simple : 
# on interdit tout par dfaut (cf. la politique par dfaut  DROP)
# puis on autorise  ce qui nous intresse :
# - l'interface locale (lo)  dialoguer avec elle-mme (c'est la moindre des choses)
# - le trafic du PC vers internet
# - le trafic d'internet vers le PC pour les connexions inities par le PC
# on interdit explicitement les paquets qui proviennent d'internet contenant 
# une adresse IP source non routable sur internet
# ensuite on ouvre les ports pour les services actifs sur notre PC et 
# qui doivent tre visibles de l'exterieur (P2P, serveur Web, ...)
# enfin on reste poli en acceptant le ping et en refusant explicitement 
# les demandes de connexions non souhaites
# sans oublier de les logguer (cf. /var/log/messages)

#
# NB : Cas du serveur X11
# Par dfaut, le serveur X est  l'coute sur le port TCP/6000. 
# On peut dsactiver cette coute en lanant le serveur X11 avec l'option '-nolisten tcp'
# (cf. fichier /etc/X11/xdm/Xservers sous Mandrakelinux) 
# ou bien on peut filtrer le port 6000 avec une rgle Netfilter.
# Exemple :
# :0 local /bin/nice -n -10 /usr/X11R6/bin/X -nolisten tcp -deferglyphs 16
# Dans ce cas, il sera impossible de faire du X  distance.
#


# A priori inutile car dj chargs
#modprobe ip_tables
#modprobe iptable_filter
#modprobe ip_conntrack
#modprobe ip_nat_ftp
#modprobe ip_nat_irc
#modprobe iptable_mangle
#modprobe iptable_nat

#########################################################################
# On part sur des bases propres : on supprime toutes rgles antrieures #
#########################################################################
# Supprime tous les filtres et les chaines existants
iptables -F
iptables -X
iptables -t nat -F
iptables -t nat -X
iptables -t mangle -F
iptables -t mangle -X 

#########################################################################################################
# Dfinition de la politique par dfaut : on ignore tout (cd absortion des paquets sans y rpondre)    #
# Puisqu'on ne dispose que d'une seule machine, on pourrait ne dfinir que la rgle sur la chane INPUT #
#########################################################################################################
iptables -P FORWARD DROP
iptables -P OUTPUT DROP
iptables -P INPUT DROP

# Autorise l'interface locale  dialoguer avec elle-mme !
iptables -A OUTPUT -o lo -s 127.0.0.0/8 -d 127.0.0.0/8 -j ACCEPT
iptables -A INPUT  -i lo -s 127.0.0.0/8 -d 127.0.0.0/8 -j ACCEPT

# Libre d'aller vers l'extrieur
iptables -A OUTPUT -m state --state ! INVALID -j ACCEPT

# Autorise le trafic entrant sur des connexions ouvertes
iptables -A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT

# Ignore les paquets provenant de l'extrieur avec une adresse non routable sur Internet
iptables -A INPUT -i ${NETIN} -s 10.0.0.0/8 -j DROP
iptables -A INPUT -i ${NETIN} -s 172.16.0.0/12 -j DROP
iptables -A INPUT -i ${NETIN} -s 192.168.0.0/16 -j DROP
iptables -A INPUT -i ${NETIN} -s 127.0.0.0/8 -j DROP

###################################
# Ouverture de ports  la demande #
###################################

# BitTorrent 
# Cette rgle autorise les clients BT  se connecter sur notre PC
# et ainsi profiter de notre bande passante montante ('upload')
# afin que notre client BT soit autoris en retour  tlcharger (principe de base du P2P)
#################################
# Pour faire du BitTorrent, activez la ligne suivante et redmarrez le script sous root.
#iptables -A INPUT -m state --state NEW -p tcp --dport 6881:6889 -j ACCEPT

# Autorise les connexions entrantes sur un serveur local.
# Crer une ligne par protocole en changeant la valeur du paramtre --dport
# Exemple de valeurs possibles :
# http, https, ftp, ssh, smtp, 53, 8080, ...            
###########################################################################
# Si vous avez un serveur HTTP et que vous vouliez qu'il soit visible depuis l'extrieur, 
# activez la ligne suivante et redmarrez le script sous root.
#iptables -A INPUT -m state --state NEW -p tcp --dport http -j ACCEPT


###############################
# La section politesse et LOG #
###############################

# Pour autoriser le ping, ie. tre visible d'internet
iptables -A INPUT -p icmp --icmp-type echo-request -j ACCEPT

# Par curiosit, on peut tracer les demandes de connexions en provenance de l'exterieur
# Traces disponibles dans le fichier /var/log/messages
iptables -A INPUT -m state --state NEW -j LOG

# Refuse explicitement les demandes de connexion
# en provenance de l'extrieur car la politique par dfaut est d'ignorer (DROP)
iptables -A INPUT -m state --state NEW -j REJECT

# fin du script
